pub struct DoctorResponse {
pub version: VersionInfo,
pub socket_path: String,
pub uptime_secs: u64,
pub sqlite: MigrationState,
pub lifecycles: LifecycleCounts,
pub watchers: WatcherCounts,
pub launchers: Vec<LauncherStatus>,
pub tmux: TmuxStatus,
pub docker: Box<DockerStatus>,
pub log_availability: Vec<LifecycleLogAvailability>,
pub last_probe_sweep: Option<DateTime<Utc>>,
pub recent_lost: Vec<RecentLostEvent>,
}Expand description
Stable v0.4 daemon diagnostics JSON.
Clients may rely on the field names and JSON value kinds in this response. The concrete diagnostic values are host and process specific.
Fields
version: VersionInfosocket_path: Stringuptime_secs: u64sqlite: MigrationStatelifecycles: LifecycleCountswatchers: WatcherCountslaunchers: Vec<LauncherStatus>tmux: TmuxStatusdocker: Box<DockerStatus>log_availability: Vec<LifecycleLogAvailability>last_probe_sweep: Option<DateTime<Utc>>recent_lost: Vec<RecentLostEvent>Trait Implementations
Sourceimpl CliOutput for DoctorResponse
impl CliOutput for DoctorResponse
fn render_human(&self, f: &mut impl Write) -> Result
Sourceimpl Clone for DoctorResponse
impl Clone for DoctorResponse
Sourcefn clone(&self) -> DoctorResponse
fn clone(&self) -> DoctorResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DoctorResponse
impl Debug for DoctorResponse
Sourceimpl<'de> Deserialize<'de> for DoctorResponse
impl<'de> Deserialize<'de> for DoctorResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DoctorResponse
impl PartialEq for DoctorResponse
Sourcefn eq(&self, other: &DoctorResponse) -> bool
fn eq(&self, other: &DoctorResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DoctorResponse
impl Serialize for DoctorResponse
impl Eq for DoctorResponse
impl StructuralPartialEq for DoctorResponse