#[non_exhaustive]pub enum RuntimeCapability {
StructuredProtocolErrors,
HeadlessStdioLogPaths,
StatusSessionSetFilter,
StatusUpdatedSinceFilter,
TypedNudgeOutcomes,
ValidateTargetPreflight,
EventsCursor,
EventsLongPoll,
TmuxPaneSnapshot,
KillOutcomes,
SpawnConflicts,
SpawnRequestMounts,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StructuredProtocolErrors
Error responses expose stable machine readable codes.
HeadlessStdioLogPaths
Headless spawn responses include stdout and stderr log paths.
StatusSessionSetFilter
Status requests accept a set of session ids.
StatusUpdatedSinceFilter
Status requests accept an updated time lower bound.
TypedNudgeOutcomes
Nudge responses expose typed delivery outcomes.
ValidateTargetPreflight
ValidateTarget checks a target string without spawning.
EventsCursor
Events support durable cursor replay.
EventsLongPoll
Events requests accept a bounded long poll wait window.
TmuxPaneSnapshot
Tmux targets support on demand pane snapshot capture.
KillOutcomes
Kill responses include typed Signalled or AlreadyExited outcomes.
SpawnConflicts
Spawn rejects session reuse and occupied tmux panes with typed conflicts.
SpawnRequestMounts
Spawn requests can carry declared host to container bind mounts.
Implementations