#[non_exhaustive]pub enum EventBatch {
Events {
events: Vec<RuntimeEvent>,
cursor: EventCursor,
},
CursorExpired {
oldest: EventCursor,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Events
CursorExpired
The watcher’s cursor has been advanced to oldest. Calling .next() again will return events from oldest onward without an intervening reconcile. The caller is expected to perform a client.status() reconcile and optionally .seek() to a freshly-discovered cursor before continuing, otherwise events will replay.
Fields

oldest: EventCursorTrait Implementations
Sourceimpl Clone for EventBatch
impl Clone for EventBatch
Sourcefn clone(&self) -> EventBatch
fn clone(&self) -> EventBatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventBatch
impl Debug for EventBatch
Sourceimpl<'de> Deserialize<'de> for EventBatch
impl<'de> Deserialize<'de> for EventBatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EventBatch
impl PartialEq for EventBatch
Sourcefn eq(&self, other: &EventBatch) -> bool
fn eq(&self, other: &EventBatch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EventBatch
impl Serialize for EventBatch
impl Eq for EventBatch
impl StructuralPartialEq for EventBatch