RuntimeCapability

Enum RuntimeCapability 

pub enum RuntimeCapability {
    StructuredProtocolErrors,
    HeadlessStdioLogPaths,
    StatusSessionSetFilter,
    StatusUpdatedSinceFilter,
    TypedNudgeOutcomes,
    ValidateTargetPreflight,
    EventsCursor,
    EventsLongPoll,
    TmuxPaneSnapshot,
    KillOutcomes,
    SpawnConflicts,
}

Variants



StructuredProtocolErrors

Error responses expose stable machine readable codes.



HeadlessStdioLogPaths

Headless spawn responses include stdout and stderr log paths.



StatusSessionSetFilter

Status requests accept a set of session ids.



StatusUpdatedSinceFilter

Status requests accept an updated time lower bound.



TypedNudgeOutcomes

Nudge responses expose typed delivery outcomes.



ValidateTargetPreflight

ValidateTarget checks a target string without spawning.



EventsCursor

Events support durable cursor replay.



EventsLongPoll

Events requests accept a bounded long poll wait window.



TmuxPaneSnapshot

Tmux targets support on demand pane snapshot capture.



KillOutcomes

Kill responses include typed Signalled or AlreadyExited outcomes.



SpawnConflicts

Spawn rejects session reuse and occupied tmux panes with typed conflicts.

Implementations

Source

impl RuntimeCapability

pub const fn as_str(self) -> &'static str